@@ -1,4 +1,4 @@
-/* $Id: tools.cc 1140 2011-11-23 06:43:27Z dreibh $
+/* $Id: tools.cc 1557 2012-11-29 18:57:57Z dreibh $
  *
  * Network Performance Meter
  * Copyright (C) 2009-2012 by Thomas Dreibholz
@@ -1151,3 +1151,32 @@ int ext_poll_wrapper(struct pollfd* fdlist, long unsigned int count, int time)
    return(result);
 }
 #endif
+
+
+ssize_t sctp_send_fixed(int                           sd,
+                        const void*                   data,
+                        size_t                        len,
+                        const struct sctp_sndrcvinfo* sinfo,
+                        int                           flags)
+{
+   struct sctp_sndrcvinfo* sri;
+   struct iovec            iov = { (char*)data, len };
+   struct cmsghdr*         cmsg;
+   size_t                  cmsglen = CMSG_SPACE(sizeof(struct sctp_sndrcvinfo));
+   char                    cbuf[CMSG_SPACE(sizeof(struct sctp_sndrcvinfo))];
+   struct msghdr msg = {
+      NULL, 0,
+      &iov, 1,
+      cbuf, cmsglen,
+      flags
+   };
+
+   cmsg = (struct cmsghdr*)CMSG_FIRSTHDR(&msg);
+   cmsg->cmsg_len   = CMSG_LEN(sizeof(struct sctp_sndrcvinfo));
+   cmsg->cmsg_level = IPPROTO_SCTP;
+   cmsg->cmsg_type  = SCTP_SNDRCV;
+
+   sri = (struct sctp_sndrcvinfo*)CMSG_DATA(cmsg);
+   memcpy(sri, sinfo, sizeof(struct sctp_sndrcvinfo));
+   return(ext_sendmsg(sd, &msg, msg.msg_flags));
+}
