@@ -1,4 +1,4 @@
-/* $Id: tools.h 1140 2011-11-23 06:43:27Z dreibh $
+/* $Id: tools.h 1557 2012-11-29 18:57:57Z dreibh $
  *
  * Network Performance Meter
  * Copyright (C) 2012 by Thomas Dreibholz
@@ -146,4 +146,14 @@ inline int ext_poll_wrapper(struct pollfd* fdlist, long unsigned int count, int
 }
 #endif
 
+#if defined(linux)
+#warning Added fix for broken sctp_send() with LK-SCTP
+ssize_t sctp_send_fixed(int                           sd,
+                        const void*                   data,
+                        size_t                        len,
+                        const struct sctp_sndrcvinfo* sinfo,
+                        int                           flags);
+#define sctp_send(a,b,c,d,e) sctp_send_fixed(a,b,c,d,e)
+#endif
+
 #endif
